# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

Name:		perl-Module-Find
Version:	0.17
Release:	1.%{__distinit}%{__distvers}
Summary:	Find and use installed modules in a (sub)category
License:	GPL-1.0-or-later OR Artistic-1.0-Perl
URL:		https://metacpan.org/release/Module-Find
Source0:	https://cpan.metacpan.org/modules/by-module/Module/Module-Find-%{version}.tar.gz
BuildArch:	noarch
# Module Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	make
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(ExtUtils::MakeMaker)
BuildRequires:	perl(Pod::Perldoc)
# Module Runtime
BuildRequires:	perl(Exporter)
BuildRequires:	perl(File::Find)
BuildRequires:	perl(File::Spec)
BuildRequires:	perl(strict)
BuildRequires:	perl(warnings)
# Test Suite
BuildRequires:	perl(lib)
BuildRequires:	perl(Test::More)
# Optional Tests
BuildRequires:	perl(Test::CPAN::Meta)
BuildRequires:	perl(Test::Pod) >= 1.14
BuildRequires:	perl(Test::Pod::Coverage) >= 1.04
# Dependencies
%if 0%{?fedora} < 38 && 0%{?rhel} < 10
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
%endif
Requires:	perl(Exporter)

%description
Module::Find lets you find and use modules in categories. This can be very
useful for auto-detecting driver or plug-in modules. You can differentiate
between looking in the category itself or in all subcategories.

%prep
%setup -q -n Module-Find-%{version}

# Generate Changes file from POD
perldoc -t Find.pm |
	perl -n -e 'if (/^HISTORY/ ... !/^[[:space:]]/) { print if /^[[:space:]]/ }' > Changes
touch --reference=Find.pm Changes

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%install
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
%{_fixperms} -c %{buildroot}

%check
make test

%files
%doc Changes README examples/
%{perl_vendorlib}/Module/
%{_mandir}/man3/Module::Find.3*

%changelog
* Mon Feb 17 2025 Paul Howarth <paul@city-fan.org> - 0.17-1
- Update to 0.17
  - Avoid warnings when extracting the distribution tarball, which prevented
    installation under cpanm and other tools (GH#13, CPAN RT#148978)

* Thu Apr 27 2023 Paul Howarth <paul@city-fan.org> - 0.16-3
- Use SPDX-format license tag

* Mon Aug  1 2022 Paul Howarth <paul@city-fan.org> - 0.16-1
- Update to 0.16
  - Fix an issue where symlink tests failed on systems that do not support
    creation of symlinks; the issue appears on Windows systems due to changed
    behaviour in File::Find described at:
    https://github.com/Perl/perl5/issues/19995
    Symlink tests were previously skipped if symlink() is not available, and
    now also if creation of a symlink is not possible
  - Fix failing symlink test on Windows
    https://github.com/crenz/Module-Find/issues/9

* Thu Dec 26 2019 Paul Howarth <paul@city-fan.org> - 0.15-1
- Update to 0.15
  - Removed file readability check (GH#4, CPAN RT#99055)
  - Now supports @INC hooks (GH#6)
  - Now filters out filenames starting with a dot (GH#7)
  - Now uses strict (GH#8)
  - Fixed CPAN RT#122016: test/ files show up in metacpan
  - Module::Find now uses @ModuleDirs (if specified) for loading modules
    (CPAN RT#127657); previously, when using setmoduledirs() to set an array
    of directories that did not contain @INC, Module::Find would find the
    modules correctly, but load them from @INC

* Mon Jun  3 2019 Paul Howarth <paul@city-fan.org> - 0.13-13
- Perl 5.30 rebuild

* Thu Apr 26 2018 Paul Howarth <paul@city-fan.org> - 0.13-9
- BR: perl-generators unconditionally
- BR: perl-interpreter rather than perl
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section

* Tue Sep  6 2016 Paul Howarth <paul@city-fan.org> - 0.13-5
- BR: perl-generators where available
- Simplify find command using -delete

* Mon Jun 22 2015 Paul Howarth <paul@city-fan.org> - 0.13-3
- Perl 5.22 rebuild

* Tue Mar 10 2015 Paul Howarth <paul@city-fan.org> - 0.13-1
- Update to 0.13
  - Link to Module::Pluggable and Class::Factory::Util in "SEE ALSO"
  - Align package name parsing with how perl does it (allowing single quotes
    as module separator)
- Classify buildreqs by usage

* Sun Aug 31 2014 Paul Howarth <paul@city-fan.org> - 0.12-3
- Drop %%defattr, redundant since rpm 4.4

* Fri Feb  7 2014 Paul Howarth <paul@city-fan.org> - 0.12-1
- Update to 0.12
  - Fixed CPAN RT#81077: useall fails in taint mode
  - Fixed CPAN RT#83596: Documentation doesn't describe behaviour if a module
    fails to load
  - Clarified documentation for useall and usesub
  - Fixed CPAN RT#62923: setmoduledirs(undef) doesn't reset to searching @INC
  - Added more explicit tests

* Fri Jun 29 2012 Paul Howarth <paul@city-fan.org> - 0.11-2
- BR: perl(lib)

* Tue May 22 2012 Paul Howarth <paul@city-fan.org> - 0.11-1
- Update to 0.11
  - defined(@array) is deprecated under Perl 5.15.7 (CPAN RT#74251)
- Don't need to remove empty directories from buildroot
- Drop support for old distributions prior to FC-3:
  - Use DESTDIR rather than PERL_INSTALL_ROOT
  - Don't need to define %%{perl_vendorlib}

* Wed Jan 25 2012 Paul Howarth <paul@city-fan.org> - 0.10-4
- BR: perl(ExtUtils::MakeMaker), perl(File::Find), perl(File::Spec) and
  perl(Pod::Perldoc)

* Thu Jun 30 2011 Paul Howarth <paul@city-fan.org> - 0.10-2
- Rebuild for perl 5.14.1 in Rawhide
- Nobody else likes macros for commands
- Fix dist tag for CentOS 6 and Scientific Linux

* Tue Mar 15 2011 Paul Howarth <paul@city-fan.org> - 0.10-1
- Import from Fedora
- Update to 0.10
  - Fixed META.yml generation (CPAN RT#38302)
  - Removed Unicode BOM from Find.pm (CPAN RT#55010)

* Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.08-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Mon Dec 20 2010 Marcela Maslanova <mmaslano@redhat.com> - 0.08-4
- Rebuild to fix problems with vendorarch/lib (#661697)

* Mon May 03 2010 Marcela Maslanova <mmaslano@redhat.com> - 0.08-3
- Mass rebuild with perl-5.12.0

* Mon Dec  7 2009 Stepan Kasal <skasal@redhat.com> - 0.08-2
- Rebuild against perl 5.10.1

* Wed Oct  7 2009 Stepan Kasal <skasal@redhat.com> - 0.08-1
- New upstream version

* Sun Jul 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.06-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Thu Feb 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.06-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Wed Jul 02 2008 Chris Weyl <cweyl@alumni.drew.edu> 0.06-1
- Update to 0.06
- Add examples/

* Fri Feb  8 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 0.05-2
- Rebuild for new perl

* Tue Dec 19 2006 Jose Pedro Oliveira <jpo at di.uminho.pt> - 0.05-1
- First build
